API Documentation
================

.. automodule:: midiogre
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   midiogre.augmentations
   midiogre.core 